#!/usr/bin/python3

from struct import pack

# change file orders to map Dx pins in a different order
# game1 files
GAME1S = (
	"PunchOut/chp1-b.6e", # game1 slave rom0 (AT27C1024 D0-D3)
	"PunchOut/chp1-b.6f", # game1 slave rom1 (AT27C1024 D4-D7)
	"PunchOut/chp1-b.7f"  # game1 slave rom2 (AT27C1024 D8-D11)
)

GAME1M = (
	"PunchOut/chp1-b.7e", # game1 master rom0 (AT27C1024 D0-D3)  
	"PunchOut/chp1-b.8e", # game1 master rom1 (AT27C1024 D4-D7)  
	"PunchOut/chp1-b.8f"  # game1 master rom2 (AT27C1024 D8-D11)
)

# game2 files
GAME2S = (
	"SuperPunchOut/chs1-b.6e", # game2 slave rom0 (AT27C1024 D0-D3)
	"SuperPunchOut/chs1-b.6f", # game2 slave rom1 (AT27C1024 D4-D7)
	"SuperPunchOut/chs1-b.7f"  # game2 slave rom2 (AT27C1024 D8-D11)
)

GAME2M = (
	"SuperPunchOut/chs1-b.7e", # game2 master rom0 (AT27C1024 D0-D3)  
	"SuperPunchOut/chs1-b.8e", # game2 master rom1 (AT27C1024 D4-D7)  
	"SuperPunchOut/chs1-b.8f"  # game2 master rom2 (AT27C1024 D8-D11)
)


def combine(romset, fpout):
	with open(romset[0], "rb") as fpi0, open(romset[1], "rb") as fpi1, open(romset[2], "rb") as fpi2:
		for addr in range(512):
			b0 = fpi0.read(1)[0] 
			b1 = fpi1.read(1)[0] 
			b2 = fpi2.read(1)[0] 
			out = 0xF000 | (b2<<8) | (b1<<4) | b0
			fpout.write(pack('<H', out))


# write slave ROM
with open("AT27C1024-S.bin", "wb") as fpo:
	for addr in range(0, 0x10000, 1024): # fill entire 64K with repeating data, so high Ax are don't care
		combine(GAME1S, fpo)
		combine(GAME2S, fpo)

# write master ROM
with open("AT27C1024-M.bin", "wb") as fpo:
	for addr in range(0, 0x10000, 1024): # fill entire 64K with repeating data, so high Ax are don't care
		combine(GAME1M, fpo)
		combine(GAME2M, fpo)
